# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class ResourceType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    決済リソース
- web WEBブラウザ
- ios iOS Nativeアプリ
- android Android Nativeアプリ
- liff Line LIFFアプリ
- mini WeChatミニプログラム
- cpm CPM決済、利用者提示型QRコード
- mpm MPM決済、店舗側提示型QRコード
- reader カードリーダー決済(リーダー設備が必要)

    """


    class MetaOapg:
        enum_value_to_name = {
            "web": "WEB",
            "ios": "IOS",
            "android": "ANDROID",
            "liff": "LIFF",
            "mini": "MINI",
            "cpm": "CPM",
            "mpm": "MPM",
            "reader": "READER",
        }
    
    @schemas.classproperty
    def WEB(cls):
        return cls("web")
    
    @schemas.classproperty
    def IOS(cls):
        return cls("ios")
    
    @schemas.classproperty
    def ANDROID(cls):
        return cls("android")
    
    @schemas.classproperty
    def LIFF(cls):
        return cls("liff")
    
    @schemas.classproperty
    def MINI(cls):
        return cls("mini")
    
    @schemas.classproperty
    def CPM(cls):
        return cls("cpm")
    
    @schemas.classproperty
    def MPM(cls):
        return cls("mpm")
    
    @schemas.classproperty
    def READER(cls):
        return cls("reader")
