from elepay.paths.terminal_readers_reader_id.get import ApiForget
from elepay.paths.terminal_readers_reader_id.delete import ApiFordelete


class TerminalReadersReaderId(
    ApiForget,
    ApiFordelete,
):
    pass
