# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.subscriptions_subscription_id_cancel.post import CancelSubscription
from elepay.paths.subscriptions.post import CreateSubscription
from elepay.paths.subscriptions_subscription_id_periods.get import ListSubscriptionPeriods
from elepay.paths.subscriptions.get import ListSubscriptions
from elepay.paths.subscriptions_subscription_id_resume.post import ResumeSubscription
from elepay.paths.subscriptions_subscription_id.get import RetrieveSubscription
from elepay.paths.subscriptions_subscription_id_start.post import StartSubscription
from elepay.paths.subscriptions_subscription_id.post import UpdateSubscription


class SubscriptionApi(
    CancelSubscription,
    CreateSubscription,
    ListSubscriptionPeriods,
    ListSubscriptions,
    ResumeSubscription,
    RetrieveSubscription,
    StartSubscription,
    UpdateSubscription,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
