from elepay.paths.subscriptions_subscription_id.get import ApiForget
from elepay.paths.subscriptions_subscription_id.post import ApiForpost


class SubscriptionsSubscriptionId(
    ApiForget,
    ApiForpost,
):
    pass
