from elepay.paths.customers_customer_id_sources_source_id.get import ApiForget
from elepay.paths.customers_customer_id_sources_source_id.delete import ApiFordelete


class CustomersCustomerIdSourcesSourceId(
    ApiForget,
    ApiFordelete,
):
    pass
