# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class SubscriptionIntervalType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    定期課金周期タイプ
- day １日１回
- week 週１回
- month 月１回
- year 年１回

    """


    class MetaOapg:
        enum_value_to_name = {
            "day": "DAY",
            "week": "WEEK",
            "month": "MONTH",
            "year": "YEAR",
        }
    
    @schemas.classproperty
    def DAY(cls):
        return cls("day")
    
    @schemas.classproperty
    def WEEK(cls):
        return cls("week")
    
    @schemas.classproperty
    def MONTH(cls):
        return cls("month")
    
    @schemas.classproperty
    def YEAR(cls):
        return cls("year")
