# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from elepay import schemas  # noqa: F401


class InvoiceStatusType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    インボイス状態

    """


    class MetaOapg:
        enum_value_to_name = {
            "draft": "DRAFT",
            "submit": "SUBMIT",
            "sent": "SENT",
            "paid": "PAID",
            "expired": "EXPIRED",
            "canceled": "CANCELED",
        }
    
    @schemas.classproperty
    def DRAFT(cls):
        return cls("draft")
    
    @schemas.classproperty
    def SUBMIT(cls):
        return cls("submit")
    
    @schemas.classproperty
    def SENT(cls):
        return cls("sent")
    
    @schemas.classproperty
    def PAID(cls):
        return cls("paid")
    
    @schemas.classproperty
    def EXPIRED(cls):
        return cls("expired")
    
    @schemas.classproperty
    def CANCELED(cls):
        return cls("canceled")
