from elepay.paths.customers_customer_id_sources.get import ApiForget
from elepay.paths.customers_customer_id_sources.post import ApiForpost


class CustomersCustomerIdSources(
    ApiForget,
    ApiForpost,
):
    pass
