# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "elepay-python-sdk"
VERSION = "1.2.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi >= 14.5.14",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "setuptools >= 21.0.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
]

with open('README.md', 'r') as readme:
    setup(
        name=NAME,
        version=VERSION,
        description="elepay API リファレンス",
        author="ELESTYLE, INC",
        author_email="support@elestyle.jp",
        url="https://github.com/elestyle/elepay-python-sdk",
        keywords=["restful", "elepay API リファレンス"],
        python_requires=">=3.7",
        install_requires=REQUIRES,
        packages=find_packages(exclude=["test", "tests"]),
        include_package_data=True,
        long_description_content_type="text/markdown",
        long_description=readme.read()
    )
