# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.invoices_invoice_id_cancel.post import CancelInvoice
from elepay.paths.invoices.post import CreateInvoice
from elepay.paths.invoices_invoice_id.delete import DeleteInvoice
from elepay.paths.invoices.get import ListInvoices
from elepay.paths.invoices_invoice_id.get import RetrieveInvoice
from elepay.paths.invoices_invoice_id_send.post import SendInvoice
from elepay.paths.invoices_invoice_id_submit.post import SubmitInvoice
from elepay.paths.invoices_invoice_id.post import UpdateInvoice


class InvoiceApi(
    CancelInvoice,
    CreateInvoice,
    DeleteInvoice,
    ListInvoices,
    RetrieveInvoice,
    SendInvoice,
    SubmitInvoice,
    UpdateInvoice,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
