# coding: utf-8

"""
    elepay API リファレンス

    elepay APIはRESTをベースに構成された決済APIです。支払い処理、返金処理など、決済に関わる運用における様々なことができます。  # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Contact: support@elestyle.jp
    Generated by: https://openapi-generator.tech
"""

from elepay.paths.customers.post import CreateCustomer
from elepay.paths.customers_customer_id_sources.post import CreateSource
from elepay.paths.customers_customer_id.delete import DeleteCustomer
from elepay.paths.customers_customer_id_sources_source_id.delete import DeleteSource
from elepay.paths.customers.get import ListCustomers
from elepay.paths.customers_customer_id_sources.get import ListSources
from elepay.paths.customers_customer_id.get import RetrieveCustomer
from elepay.paths.customers_customer_id_sources_source_id.get import RetrieveSource
from elepay.paths.sources_source_id_status.get import RetrieveSourceStatus
from elepay.paths.customers_customer_id.post import UpdateCustomer


class CustomerApi(
    CreateCustomer,
    CreateSource,
    DeleteCustomer,
    DeleteSource,
    ListCustomers,
    ListSources,
    RetrieveCustomer,
    RetrieveSource,
    RetrieveSourceStatus,
    UpdateCustomer,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
